@@ -327,7 +327,7 @@ class AutoStreaming:
                 gateway = StreamingGateway(
                     session=self.session,
                     service_id=service_id,
-                    output_config=self.output_configs.get(gateway_id, None),
+                    output_config=self.output_configs,
                     inputs_config=input_configs,
                     result_callback=self.result_callback,
                     strip_input_from_result=self.strip_input_from_result,
