@@ -24,11 +24,15 @@ from .core.config import (
     BaseConfig, 
     PeopleCountingConfig, 
     CustomerServiceConfig,
+    IntrusionConfig,
+    ProximityConfig,
     config_manager,
     ConfigValidationError
 )
 from .usecases import (
     PeopleCountingUseCase,
+    IntrusionUseCase,
+    ProximityUseCase,
     CustomerServiceUseCase,
     AdvancedCustomerServiceUseCase,
     LicensePlateUseCase,
@@ -60,6 +64,8 @@ from .usecases import (
     ShelfInventoryUseCase,
     LaneDetectionUseCase,
     LitterDetectionUseCase,
+    AbandonedObjectDetectionUseCase,
+
     LeakDetectionUseCase,
     HumanActivityUseCase,
     GasLeakDetectionUseCase,
@@ -69,7 +75,6 @@ from .usecases import (
     WeldDefectUseCase,
     WeaponDetectionUseCase,
 
-    AgeDetectionUseCase,
     PriceTagUseCase,
     DistractedDriverUseCase,
     EmergencyVehicleUseCase,
@@ -150,6 +155,12 @@ class PostProcessor:
         # Register people counting use case
         registry.register_use_case("general", "people_counting", PeopleCountingUseCase)
         
+        # Register intrusion detection use case
+        registry.register_use_case("security", "intrusion_detection", IntrusionUseCase)
+        
+        # Register proximity detection use case
+        registry.register_use_case("security", "proximity_detection", ProximityUseCase)
+        
         # Register customer service use case
         registry.register_use_case("sales", "customer_service", CustomerServiceUseCase)
         
@@ -177,7 +188,7 @@ class PostProcessor:
         registry.register_use_case("security", "anti_spoofing_detection", AntiSpoofingDetectionUseCase)
         registry.register_use_case("retail", "shelf_inventory", ShelfInventoryUseCase)
         registry.register_use_case("traffic", "lane_detection", LaneDetectionUseCase)
-        
+        registry.register_use_case("security", "abandoned_object_detection", AbandonedObjectDetectionUseCase)
         registry.register_use_case("hazard", "fire_smoke_detection", FireSmokeUseCase)
         registry.register_use_case("flare_detection", "flare_analysis", FlareAnalysisUseCase)
         registry.register_use_case("general", "face_emotion", FaceEmotionUseCase)
@@ -224,7 +235,7 @@ class PostProcessor:
         registry.register_use_case("agriculture", "waterbody_segmentation", WaterBodyUseCase)
         registry.register_use_case("litter_detection", "litter_detection", LitterDetectionUseCase)
         registry.register_use_case("oil_gas", "leak_detection", LeakDetectionUseCase)
-        registry.register_use_case("general", "human_activity", HumanActivityUseCase)
+        registry.register_use_case("general", "human_activity_recognition", HumanActivityUseCase)
         registry.register_use_case("oil_gas", "gas_leak_detection", GasLeakDetectionUseCase)
 
         #Put all IMAGE based usecases here
@@ -333,8 +344,8 @@ class PostProcessor:
             elif isinstance(use_case, ChickenPoseDetectionUseCase):
                 result = use_case.process(data, parsed_config, context, stream_info)
             elif isinstance(use_case, FlareAnalysisUseCase):
-                result = use_case.process(data, parsed_config,input_bytes, context, stream_info)
-            elif isinstance(use_case,LicensePlateUseCase):
+                result = use_case.process(data, parsed_config, input_bytes, context, stream_info)
+            elif isinstance(use_case, LicensePlateUseCase):
                 result = use_case.process(data, parsed_config, context, stream_info)
             elif isinstance(use_case, CropWeedDetectionUseCase):
                 result = use_case.process(data, parsed_config, context, stream_info)
@@ -364,7 +375,8 @@ class PostProcessor:
                 result = use_case.process(data, parsed_config, context, stream_info)
             elif isinstance(use_case, LaneDetectionUseCase):
                 result = use_case.process(data, parsed_config, context, stream_info)
-
+            elif isinstance(use_case, AbandonedObjectDetectionUseCase):
+                result = use_case.process(data, parsed_config, context, stream_info)
             elif isinstance(use_case, WindmillMaintenanceUseCase):
                 result = use_case.process(data, parsed_config, context, stream_info)
 
