@@ -23,6 +23,7 @@ from ..core.config import BaseConfig, AlertConfig, ZoneConfig
 class AbandonedObjectConfig(BaseConfig):
     """Configuration for abandoned object detection use case."""
     enable_smoothing: bool = True
+    centroid_threshold: float = 10.0
     smoothing_algorithm: str = "observability"
     smoothing_window_size: int = 20
     smoothing_cooldown_frames: int = 5
@@ -193,7 +194,7 @@ class AbandonedObjectDetectionUseCase(BaseProcessor):
                 track_info['bbox'] = bbox
 
                 # Check if centroid has moved significantly
-                if self._is_centroid_stationary(centroid, prev_centroid):
+                if self._is_centroid_stationary(centroid, prev_centroid, config.centroid_threshold):
                     if track_info['frame_count'] >= config.stationary_threshold_frames:
                         # Check for overlap with person
                         if not self._overlaps_with_person(bbox):
@@ -222,6 +223,7 @@ class AbandonedObjectDetectionUseCase(BaseProcessor):
 
     def _is_centroid_stationary(self, centroid: tuple, prev_centroid: tuple, threshold: float = 5.0) -> bool:
         """Check if centroid movement is within threshold."""
+        threshold = threshold or self.config.centroid_threshold
         x1, y1 = centroid
         x2, y2 = prev_centroid
         distance = ((x1 - x2) ** 2 + (y1 - y2) ** 2) ** 0.5
@@ -230,7 +232,7 @@ class AbandonedObjectDetectionUseCase(BaseProcessor):
     def _overlaps_with_person(self, bbox: Dict) -> bool:
         """Check if bbox overlaps with any person bbox."""
         for person_bbox in self._person_bboxes:
-            if person_bbox and self._compute_iou(bbox, person_bbox) > 0.1:
+            if person_bbox and self._compute_iou(bbox, person_bbox) > 0.5:
                 return True
         return False
 
