@@ -35,9 +35,16 @@ class ColorDetectionConfig(BaseConfig):
     confidence_threshold: float = 0.5
     top_k_colors: int = 3
     frame_skip: int = 1
-    target_categories: Optional[List[str]] = field(default_factory=lambda: [
-        "person", "people", "car", "cars", "truck", "trucks", "motorcycle", "motorcycles", "vehicle", "vehicles", "bus", "bicycle"
-    ])
+    usecase_categories: List[str] = field(
+        default_factory=lambda: [
+            "bicycle", "car", "motorbike", "auto rickshaw", "bus", "garbagevan",
+            "truck", "minibus", "army vehicle", "pickup", "policecar", "rickshaw",
+            "scooter", "suv", "taxi", "three wheelers -CNG-", "human hauler", "van", "wheelbarrow"
+        ]
+    )
+    target_categories: List[str] = field(
+        default_factory=lambda: ['car', 'bicycle', 'bus', 'garbagevan', 'truck', 'motorbike', 'van']
+    )
     fps: Optional[float] = None
     bbox_format: str = "auto"
     index_to_category: Optional[Dict[int, str]] = None
@@ -51,6 +58,30 @@ class ColorDetectionConfig(BaseConfig):
     smoothing_window_size: int = 20
     smoothing_cooldown_frames: int = 5
     smoothing_confidence_range_factor: float = 0.5
+    index_to_category: Optional[Dict[int, str]] = field(
+        default_factory=lambda: {
+                0: "ambulance",
+                1: "army vehicle",
+                2: "car",
+                3: "bicycle",
+                4: "bus",
+                5: "auto rickshaw",
+                6: "garbagevan",
+                7: "truck",
+                8: "minibus",
+                9: "minivan",
+                10: "motorbike",
+                11: "pickup",
+                12: "policecar",
+                13: "rickshaw",
+                14: "scooter",
+                15: "suv",
+                16: "taxi",
+                17: "three wheelers -CNG-",
+                18: "human hauler",
+                19: "van",
+                20: "wheelbarrow"
+            })
 
     def validate(self) -> List[str]:
         """Validate configuration parameters."""
@@ -74,12 +105,20 @@ class ColorDetectionConfig(BaseConfig):
 
 class ColorDetectionUseCase(BaseProcessor):
     """Color detection processor for analyzing object colors in video streams with tracking."""
+    CATEGORY_DISPLAY = {
+        "bicycle": "Bicycle", "car": "Car", "motorbike": "Motorbike", "auto rickshaw": "Auto Rickshaw",
+        "bus": "Bus", "garbagevan": "Garbage Van", "truck": "Truck", "minibus": "Minibus",
+        "army vehicle": "Army Vehicle", "pickup": "Pickup", "policecar": "Police Car",
+        "rickshaw": "Rickshaw", "scooter": "Scooter", "suv": "SUV", "taxi": "Taxi",
+        "three wheelers -CNG-": "Three Wheelers (CNG)", "human hauler": "Human Hauler",
+        "van": "Van", "wheelbarrow": "Wheelbarrow"
+    }
     
     def __init__(self):
         super().__init__("color_detection")
         self.category = "visual_appearance"
         
-        self.target_categories = ["person", "people", "car", "cars", "truck", "trucks", "motorcycle", "motorcycles", "vehicle", "vehicles", "bus", "bicycle"]
+        self.target_categories = ['car', 'bicycle', 'bus', 'garbagevan', 'truck', 'motorbike', 'van']
         
         self.CASE_TYPE: Optional[str] = 'color_detection'
         self.CASE_VERSION: Optional[str] = '1.3'
@@ -292,10 +331,14 @@ class ColorDetectionUseCase(BaseProcessor):
             if config.index_to_category:
                 processed_data = apply_category_mapping(processed_data, config.index_to_category)
                 self.logger.debug("Applied category mapping")
+
+            if config.target_categories:
+                color_processed_data = [d for d in processed_data if d.get('category') in self.target_categories]
+                self.logger.debug("Applied category filtering")
             
             # Step 2.5: Filter to only include target categories
-            color_processed_data = filter_by_categories(processed_data.copy(), config.target_categories)
-            self.logger.debug(f"Applied target category filtering for: {config.target_categories}")
+            # color_processed_data = filter_by_categories(processed_data.copy(), config.target_categories)
+            # self.logger.debug(f"Applied target category filtering for: {config.target_categories}")
             
             raw_processed_data = [copy.deepcopy(det) for det in color_processed_data]
             # Step 3: Apply bounding box smoothing if enabled
